pub struct RegisteredQuery {
pub id: u64,
pub owner: String,
pub query_type: String,
pub keys: Vec<KvKey>,
pub transactions_filter: String,
pub connection_id: String,
pub update_period: u64,
pub last_submitted_result_local_height: u64,
pub last_submitted_result_remote_height: Option<Height>,
pub deposit: Vec<Coin>,
pub submit_timeout: u64,
pub registered_at_height: u64,
}Expand description
Information about an Interchain Query registered in the interchainqueries module.
Fields
id: u64The unique id of the registered query.
owner: StringThe address of the contract that registered the query.
query_type: StringThe query type identifier: kv or tx.
keys: Vec<KvKey>The KV-storage keys for which to get values from the remote chain. Only applicable for the
KV Interchain Queries. Max amount of keys is limited by the module’s max_kv_query_keys_count
parameters.
transactions_filter: StringA stringified list of filters for remote transactions search. Only applicable for the TX
Interchain Queries. Example: “[{"field":"tx.height","op":"Gte","value":2644737}]”.
Supported operators: “eq”, “lt”, “gt”, “lte”, “gte”. Max amount of filter conditions is limited
by the module’s max_transactions_filters parameters.
connection_id: StringThe IBC connection ID to the remote chain (the source of querying data). Is used for getting ConsensusState from the respective IBC client to verify query result proofs.
update_period: u64Parameter that defines the minimal delay between consecutive query executions (i.e. the minimal delay between query results update).
last_submitted_result_local_height: u64The local chain block height of the last query results update.
last_submitted_result_remote_height: Option<Height>The remote chain block height that corresponds to the last query result update.
deposit: Vec<Coin>Amount of coins paid for the Interchain Query registration. The deposit is paid back to the remover. The remover can be either the query owner (during the submit timeout) or anybody.
submit_timeout: u64The duration, measured in blocks, that must pass since the query’s registration or its last result submission before the query becomes eligible for removal by anyone.
registered_at_height: u64The local chain block height of the Interchain Query registration.
Implementations